macro_rules! try_debug {
($l:expr, #$tag:expr, $($args:tt)+) => { ... };
($l:expr, $($args:tt)+) => { ... };
}Expand description
Log a debug level message if the given logger is Some, otherwise do nothing.
macro_rules! try_debug {
($l:expr, #$tag:expr, $($args:tt)+) => { ... };
($l:expr, $($args:tt)+) => { ... };
}Log a debug level message if the given logger is Some, otherwise do nothing.