macro_rules! try_error {
($l:expr, #$tag:expr, $($args:tt)+) => { ... };
($l:expr, $($args:tt)+) => { ... };
}Expand description
Log an error level message if the given logger is Some, otherwise do nothing.
macro_rules! try_error {
($l:expr, #$tag:expr, $($args:tt)+) => { ... };
($l:expr, $($args:tt)+) => { ... };
}Log an error level message if the given logger is Some, otherwise do nothing.